<?php
if (!defined('_PS_VERSION_'))
    exit;

require_once __DIR__ . "/../vendor/php-curl/src/cURL.php";
require_once __DIR__ . "/../vendor/php-curl/src/cURLException.php";
require_once __DIR__ . "/../vendor/php-curl/src/Request.php";
require_once __DIR__ . "/../vendor/php-curl/src/Response.php";

function upgrade_module_1_7($module)
{
    if(
            !Configuration::deleteByName('TR_LEAD_POPUP_ENABLED') ||
            !Configuration::deleteByName('TR_ENABLED') ||
            !Configuration::deleteByName('TR_ENABLED_ADVERTISER') ||
            !Configuration::deleteByName('TR_ENABLED_DISTRIBUTOR') ||
            !Configuration::deleteByName('TR_PASS_COD_FISC') ||
            !Configuration::deleteByName('TR_PASS_SEX') ||
            !Configuration::deleteByName('TR_PASS_PHONE')) return false;
    
    tr_autoenable_v2_integration();
    return true;
}

/**
 * Tell the server to enable V2 mode.
 * The server replies with the new auth key, which will automatically replace the old one. 
 */
function tr_autoenable_v2_integration()
{
    $apiKey = Configuration::get('TR_API_KEY');
    if (!$apiKey) return;

    // Skip if the key has already been switched
    if (strlen($apiKey < 40)) return;

    $response = tr_callAPI('get', 'plugins/switchToV2');
    
    if ($response->statusCode == 200) {
        Configuration::updateValue('TR_API_KEY', $response->body);
        return true;
    }

    // If the switch failed, remove the existing key to disable the plugin
    Configuration::updateValue('TR_API_KEY', '');
    return false;
}

function tr_callAPI($method, $endpoint, $payload=[])
{
    $api_key = Configuration::get('TR_API_KEY');
    $tr_host = Configuration::get('TR_HOST');

    $completeEndpointUrl = $tr_host . "/api/v1/" . $endpoint;

    $headers = array(
        "X-Authorization" => $api_key,
        "Content-Type" => "application/json",
        "Accept" => "application/json",
        "X-Platform" => 'Prestashop',
        "X-Platform-Version" =>  _PS_VERSION_,
        "X-Integration-Version" => '1.7'
    );

    $curl = new anlutro\cURL\cURL;
    $curl->setDefaultHeaders($headers);

    try {
        switch($method) {
            case 'get':
                $response = $curl->get($completeEndpointUrl);
                break;
            case 'post':
                $response = $curl->rawPost($completeEndpointUrl, json_encode($payload));
                break;
            default:
                return null;
        }

        if($response->statusCode <= 300) {
            if (_PS_MODE_DEV_ === true) {
                Logger::addLog('Transactionale success: ' . $response->body, 1, $response->statusCode);
            }
            return $response;
        }

        Logger::addLog('Transactionale error: ' . $response->body, 2, $response->statusCode);

        return $response;
    } catch(Exception $err) {
        Logger::addLog('Transactionale exception: ' . $err->getMessage(), 3);
        return $err->getMessage();
    }

}